summaryrefslogtreecommitdiff
path: root/png.c
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2002-05-10 20:19:58 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:07:06 -0500
commit837a3d17450efb9134412e445679d283669ff070 (patch)
treedd574690fe67585416718262ec1246a12f2547ab /png.c
parent704228f7e71191d711be50ee56be0bbcf7b2afd6 (diff)
downloadlibpng-837a3d17450efb9134412e445679d283669ff070.tar.gz
Imported from libpng-1.2.3rc5.tarv1.2.3rc5
Diffstat (limited to 'png.c')
-rw-r--r--png.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/png.c b/png.c
index 09c1ec7d6..188f687f8 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* libpng version 1.2.3rc4 - May 3, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -13,14 +13,14 @@
#include "png.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_2_3rc4 Your_png_h_is_not_version_1_2_3rc4;
+typedef version_1_2_3rc5 Your_png_h_is_not_version_1_2_3rc5;
/* Version information for C files. This had better match the version
* string defined in png.h. */
#ifdef PNG_USE_GLOBAL_ARRAYS
/* png_libpng_ver was changed to a function in version 1.0.5c */
-const char png_libpng_ver[18] = "1.2.3rc4";
+const char png_libpng_ver[18] = "1.2.3rc5";
/* png_sig was changed to a function in version 1.0.5c */
/* Place to hold the signature string for a PNG file. */
@@ -663,7 +663,7 @@ png_charp PNGAPI
png_get_copyright(png_structp png_ptr)
{
if (png_ptr != NULL || png_ptr == NULL) /* silence compiler warning */
- return ((png_charp) "\n libpng version 1.2.3rc4 - May 3, 2002\n\
+ return ((png_charp) "\n libpng version 1.2.3rc5 - May 11, 2002\n\
Copyright (c) 1998-2002 Glenn Randers-Pehrson\n\
Copyright (c) 1996-1997 Andreas Dilger\n\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.\n");
@@ -681,8 +681,8 @@ png_get_libpng_ver(png_structp png_ptr)
{
/* Version of *.c files used when building libpng */
if(png_ptr != NULL) /* silence compiler warning about unused png_ptr */
- return((png_charp) "1.2.3rc4");
- return((png_charp) "1.2.3rc4");
+ return((png_charp) "1.2.3rc5");
+ return((png_charp) "1.2.3rc5");
}
png_charp PNGAPI
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * libpng version 1.2.3rc4 - May 3, 2002
+ * libpng version 1.2.3rc5 - May 11, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)